<?php

declare(strict_types=1);

namespace Drupal\captcha_captchetat\Helper;

use Drupal\captcha_captchetat\Client\CaptchaClientInterface;

/**
 * Provide a client helper interface.
 */
interface ClientHelperInterface {

  /**
   * Get Captcha client current version.
   *
   * @param string $mode
   *   The captcha loading mode.
   * @param string $objectType
   *   The object type to get.
   * @param string|null $captchaType
   *   The captcha type to get.
   * @param string|null $captchaId
   *   The captcha identifier (if captcha is already generated).
   *
   * @return string
   *   The captcha HTML element.
   */
  public function getCaptcha(
    string $mode = CaptchaClientInterface::MODE_FRONTAL,
    string $objectType = CaptchaClientInterface::OBJECT_TYPE_HTML,
    ?string $captchaType = NULL,
    ?string $captchaId = NULL
  ): string;

  /**
   * Get the captcha input identifier.
   *
   * @return string
   *   The catpcha input identifier.
   */
  public function getInputId(): string;

  /**
   * Get captcha client current version.
   *
   * @return string
   *   The client version.
   */
  public function getVersion(): string;

  /**
   * Check captcha client is available.
   *
   * @return bool
   *   True if the client is available, false otherwise.
   */
  public function isAvailable(): bool;

  /**
   * Check captcha input code for given identifier.
   *
   * @param string $captchaId
   *   The captcha identifier.
   * @param string $code
   *   The code input by the user.
   *
   * @return bool
   *   True if the code is valid, false otherwise.
   */
  public function isCaptchaValid(string $captchaId, string $code): bool;

}
